@@ -46,11 +46,15 @@ class DefaultChildWatcher(asyncio.AbstractChildWatcher):
 
     _strategy: Optional[ChildStrategy]
 
-    def __init__(self):
+    def __init__(self, *, thread_strategy=False):
         "Initialize child watcher."
         self._strategy = None
         self._lock = threading.Lock()
 
+        if thread_strategy:
+            # Force use of ThreadStrategy for coverage test.
+            self._strategy = ThreadStrategy()
+
     def add_child_handler(self, pid, callback, *args):
         """Register a new child handler.
 
